@@ -1,15 +1,16 @@
 /**
  * @file js/classes/Handler.js
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class Handler
  * @ingroup js_classes
  *
  * @brief Base class for handlers bound to a DOM HTML element.
  */
+/*global _, pkp */
 (function($) {
 
 
@@ -23,6 +24,7 @@
 	 * @param {Object} options Handler options.
 	 */
 	$.pkp.classes.Handler = function($element, options) {
+		var $parents, self, i;
 
 		// Check whether a single element was passed in.
 		if ($element.length > 1) {
@@ -43,6 +45,21 @@
 		this.eventBindings_ = { };
 		this.dataItems_ = { };
 		this.publishedEvents_ = { };
+		this.handlerChildren_ = [];
+		this.globalEventListeners_ = { };
+
+		// Register this handler with a parent handler if one is found. This
+		// allows global events to be de-registered when a parent handler is
+		// refreshed.
+		$parents = this.$htmlElement_.parents();
+		self = this;
+		$parents.each(function(i) {
+			if ($.pkp.classes.Handler.hasHandler($($parents[i]))) {
+				$.pkp.classes.Handler.getHandler($($parents[i]))
+						.handlerChildren_.push(self);
+				return; // only attach to the closest parent handler
+			}
+		});
 
 		if (options.eventBridge) {
 			// Configure the event bridge.
@@ -54,7 +71,6 @@
 		// content change.
 		if (options.publishChangeEvents) {
 			this.publishChangeEvents_ = options.publishChangeEvents;
-			var i;
 			for (i = 0; i < this.publishChangeEvents_.length; i++) {
 				this.publishEvent(this.publishChangeEvents_[i]);
 			}
@@ -119,6 +135,15 @@
 	$.pkp.classes.Handler.prototype.eventBridge_ = null;
 
 
+	/**
+	 * Global event bindings. These are tracked so they can be deregistered when
+	 * the handler is destroyed.
+	 * @private
+	 * @type {Object}
+	 */
+	$.pkp.classes.Handler.prototype.globalEventListeners_ = null;
+
+
 	//
 	// Public static methods
 	//
@@ -146,6 +171,17 @@
 	};
 
 
+	/**
+	 * Check if a jQuery element has a handler bound to it
+	 *
+	 * @param {jQueryObject} $element The element to check for a handler
+	 * @return {boolean}
+	 */
+	$.pkp.classes.Handler.hasHandler = function($element) {
+		return $element.data('pkp.handler') instanceof $.pkp.classes.Handler;
+	};
+
+
 	//
 	// Public methods
 	//
@@ -300,6 +336,9 @@
 		// Remove all event handlers in our namespace.
 		$element = this.getHtmlElement();
 		$element.unbind('.pkpHandler');
+		// form-success which is registered in ModalHandler was not
+		// removed when Modal closed. This ensures that binding is removed.
+		this.unbindGlobalAll();
 
 		// Remove all our data items except for the
 		// handler itself.
@@ -327,18 +366,22 @@
 	 *  false if an error occurred.
 	 */
 	$.pkp.classes.Handler.prototype.handleJson = function(jsonData) {
+		var key, eventData;
+
 		if (!jsonData) {
 			throw new Error('Server error: Server returned no or invalid data!');
 		}
 
 		if (jsonData.status === true) {
-			// Did the server respond with an event to be triggered?
-			if (jsonData.event) {
-				if (jsonData.event.data) {
-					this.trigger(jsonData.event.name,
-							jsonData.event.data);
+			// Trigger events passed from the server
+			for (key in jsonData.events) {
+				eventData = jsonData.events[key].hasOwnProperty('data') ?
+						jsonData.events[key].data : null;
+				if (eventData !== null && eventData.isGlobalEvent) {
+					eventData.handler = this;
+					pkp.eventBus.$emit(jsonData.events[key].name, eventData);
 				} else {
-					this.trigger(jsonData.event.name);
+					this.trigger(jsonData.events[key].name, eventData);
 				}
 			}
 			return jsonData;
@@ -449,6 +492,84 @@
 	};
 
 
+	/**
+	 * Bind a global event to a handler operation.
+	 *
+	 * Binds a callback function to fire when a global event is triggered on
+	 * the global event router.
+	 *
+	 * @param {string} eventName The name of the event to bind to.
+	 * @param {Function} callback The function to firewhen the event is triggered
+	 */
+	$.pkp.classes.Handler.prototype.bindGlobal = function(eventName, callback) {
+		if (typeof this.globalEventListeners_[eventName] === 'undefined') {
+			this.globalEventListeners_[eventName] = [];
+		}
+		var wrapper = this.callbackWrapper(callback);
+		this.globalEventListeners_[eventName].push(wrapper);
+		pkp.eventBus.$on(eventName, wrapper);
+	};
+
+
+	/**
+	 * Unbind a global event from a handler operation.
+	 *
+	 * If passing a `null` callback, all callbacks bound to eventName by this
+	 * handler will be unbound. See: http://backbonejs.org/#Events-off
+	 *
+	 * @see $.pkp.classes.Handler.prototype.bindGlobal()
+	 * @param {string} eventName The name of the event to bind to
+	 * @param {Function} callback The function to fire when event is triggered
+	 */
+	$.pkp.classes.Handler.prototype.unbindGlobal = function(eventName, callback) {
+		var wrapper = this.callbackWrapper(callback),
+				globalEventListeners = [];
+		if (typeof this.globalEventListeners_[eventName] !== 'undefined') {
+			this.globalEventListeners.forEach(function(callback) {
+				if (callback !== wrapper) {
+					globalEventListeners.push(callback);
+				}
+			});
+			this.globalEventListeners = globalEventListeners;
+		}
+		pkp.eventBus.$off(eventName, wrapper);
+	};
+
+
+	/**
+	 * Unbind all global event listeners on this handler and any child handlers
+	 */
+	$.pkp.classes.Handler.prototype.unbindGlobalAll = function() {
+		var event, callback;
+		if (typeof this.globalEventListeners_ !== 'undefined') {
+			for (event in this.globalEventListeners_) {
+				for (callback in this.globalEventListeners_[event]) {
+					pkp.eventBus.$off(event, this.globalEventListeners_[event][callback]);
+				}
+			}
+		}
+		this.globalEventListeners = null;
+		this.unbindGlobalChildren();
+	};
+
+
+	/**
+	 * Unbind all global event listeners on child handlers
+	 */
+	$.pkp.classes.Handler.prototype.unbindGlobalChildren = function() {
+		this.handlerChildren_.forEach(function(childHandler) {
+			// Handler in legacy JS framework
+			if (typeof childHandler.unbindGlobalAll !== 'undefined') {
+				childHandler.unbindGlobalAll();
+			// Handler in new Vue.js framework
+			} else if (typeof childHandler.$destroy !== 'undefined') {
+				delete pkp.registry._instances[childHandler.id];
+				childHandler.$destroy();
+			}
+		});
+	};
+
+
 	/**
 	 * Add or retrieve a data item to/from the DOM element
 	 * this handler is managing.
@@ -571,7 +692,7 @@
 		if (typeof tinyMCE !== 'undefined') {
 			var $element = this.getHtmlElement(),
 					elementId = $element.attr('id'),
-					settings = tinyMCE.EditorManager.settings;
+					settings = $.pkp.controllers.SiteHandler.prototype.tinymceParams_;
 
 			settings.defaultToolbar = settings.toolbar;
 
@@ -580,7 +701,7 @@
 						icon = $('<div></div>'),
 						iconParent = $('<div></div>'),
 						classes, i, editor,
-						settings = tinyMCE.EditorManager.settings;
+						settings = $.pkp.controllers.SiteHandler.prototype.tinymceParams_;
 
 				// Set the extended toolbar, if requested
 				if ($(this).hasClass('extendedRichContent')) {
@@ -648,6 +769,100 @@
 	};
 
 
+	/**
+	 * Wrapper for the jQuery .replaceWith() function.
+	 *
+	 * This unbinds all global events before replacing the HTML content, to
+	 * ensure there are no orphaned event listeners lingering from handlers
+	 * which may have been destroyed when the HTML was replaced.
+	 *
+	 * This function can only be used when the entire handler is replaced. For
+	 * replacing parts of a handler, see replacePartialWith().
+	 *
+	 * @param {string|jQueryObject} html The HTML content to replace the
+	 *  current element with
+	 */
+	$.pkp.classes.Handler.prototype.replaceWith = function(html) {
+		this.unbindGlobalAll();
+		this.getHtmlElement().replaceWith(html);
+	};
+
+
+	/**
+	 * Wrapper for the jQuery .replaceWith() function.
+	 *
+	 * This function works like the .replaceWith() wrapper above, except it
+	 * allows you to pass a specific dom element to replace within the Handler.
+	 *
+	 * This function loops over any handlers found within the $partial dom
+	 * element, unbinding global events to ensure there are no orphaned event
+	 * listeners when the HTML element is replaced.
+	 *
+	 * The .replaceWith() function is preferred in most cases. This should only
+	 * been used when you _need_ to replace part of a Handler's HTML content.
+	 * Full handler refreshes are preferred to keep things simple. Also, this
+	 * function isn't very performant, because it requires looping over every
+	 * child DOM element.
+	 *
+	 * @param {string|jQueryObject} html The HTML content to inject into
+	 *  the $partial
+	 * @param {jQueryObject} $partial The HTML element to unbind
+	 */
+	$.pkp.classes.Handler.prototype.replacePartialWith =
+			function(html, $partial) {
+
+		// Check if the $partial already has a handler bound to it on which
+		// we can call .unbindGlobalAll() instead
+		if ($.pkp.classes.Handler.hasHandler($partial)) {
+			$.pkp.classes.Handler.getHandler($partial).replaceWith(html);
+			return;
+		}
+
+		this.unbindPartial($partial);
+		$partial.replaceWith(html);
+	};
+
+
+	/**
+	 * Wrapper for the jQuery .html() function.
+	 *
+	 * This unbinds all global events before replacing the inner HTML content.
+	 * It differs from the .replaceWith() wrapper function in that the handler's
+	 * element is not removed. This means the handler isn't re-initialized, and
+	 * so only child handler events need to be unbound.
+	 *
+	 * @param {string} html The HTML content to inject into the $partial
+	 */
+	$.pkp.classes.Handler.prototype.html = function(html) {
+		this.unbindGlobalChildren();
+		this.getHtmlElement().html(html);
+	};
+
+
+	/**
+	 * This function loops over any handlers found within the $partial dom
+	 * element, unbinding global events to ensure there are no orphaned event
+	 * listeners when the HTML element is replaced.
+	 *
+	 * This function isn't very performant. It requires looping over every
+	 * element in scope, which could potentially be hundreds or thousands.
+	 * This should only be used as a last resort for some handlers which need
+	 * to empty out partial content, such as tabs and grids.
+	 *
+	 * @param {jQueryObject} $partial The HTML element to unbind
+	 */
+	$.pkp.classes.Handler.prototype.unbindPartial =
+			function($partial) {
+
+		$('*', $partial).each(function() {
+			if ($.pkp.classes.Handler.hasHandler($(this))) {
+				var handler = $.pkp.classes.Handler.getHandler($(this));
+				handler.callbackWrapper(handler.unbindGlobalAll());
+			}
+		});
+	};
+
+
 	//
 	// Private static methods
 	//
@@ -665,5 +880,4 @@
 	};
 
 
-/** @param {jQuery} $ jQuery closure. */
 }(jQuery));
