@@ -17,12 +17,15 @@
 namespace APP\pages\issue;
 
 use APP\core\Application;
+use APP\core\Request;
 use APP\facades\Repo;
 use APP\file\IssueFileManager;
 use APP\handler\Handler;
 use APP\issue\Collector;
+use APP\issue\Issue;
 use APP\issue\IssueAction;
 use APP\issue\IssueGalleyDAO;
+use APP\journal\Journal;
 use APP\observers\events\UsageEvent;
 use APP\payment\ojs\OJSCompletedPaymentDAO;
 use APP\payment\ojs\OJSPaymentManager;
@@ -38,6 +41,7 @@ use PKP\security\authorization\ContextRequiredPolicy;
 use PKP\security\Validation;
 use PKP\submission\GenreDAO;
 use PKP\submission\PKPSubmission;
+use PKP\userGroup\UserGroup;
 
 class IssueHandler extends Handler
 {
@@ -76,7 +80,7 @@ class IssueHandler extends Handler
 
             // Invalid galley id, redirect to issue page
             if (!$galley) {
-                $request->redirect(null, null, 'view', $issue->getId());
+                $request->redirect(null, null, 'view', [$issue->getId()]);
             }
 
             $this->setGalley($galley);
@@ -100,7 +104,7 @@ class IssueHandler extends Handler
         $issue = Repo::issue()->getCurrent($journal->getId(), true);
 
         if ($issue != null) {
-            $request->redirect(null, 'issue', 'view', $issue->getBestIssueId());
+            $request->redirect(null, 'issue', 'view', [$issue->getBestIssueId()]);
         }
 
         $this->setupTemplate($request);
@@ -116,6 +120,8 @@ class IssueHandler extends Handler
      *
      * @param array $args
      * @param \APP\core\Request $request
+     *
+     * @hook IssueHandler::view::galley [[&$request, &$issue, &$galley]]
      */
     public function view($args, $request)
     {
@@ -129,7 +135,7 @@ class IssueHandler extends Handler
                 $request->redirect(null, null, 'download', [$issue->getBestIssueId($journal), $galley->getBestGalleyId()]);
             }
         } else {
-            self::_setupIssueTemplate($request, $issue, $request->getUserVar('showToc') ? true : false);
+            self::_setupIssueTemplate($request, $issue, $journal, $request->getUserVar('showToc') ? true : false);
             $templateMgr->assign('issueId', $issue->getBestIssueId());
 
             // consider public identifiers
@@ -173,7 +179,7 @@ class IssueHandler extends Handler
         $prevPage = $showingStart > 1 ? $page - 1 : null;
 
         if (!count($issues) && $offset) {
-            $this->getDispatcher()->handle404();
+            throw new \Symfony\Component\HttpKernel\Exception\NotFoundHttpException();
         }
 
         $templateMgr->assign([
@@ -193,6 +199,8 @@ class IssueHandler extends Handler
      *
      * @param array $args ($issueId, $galleyId)
      * @param \APP\core\Request $request
+     *
+     * @hook IssueHandler::download [[&$issue, &$galley]]
      */
     public function download($args, $request)
     {
@@ -241,7 +249,7 @@ class IssueHandler extends Handler
         $issueAction = new IssueAction();
 
         $journal = $request->getJournal();
-        $user = $request->getUser();
+        $user = $request->getUser(); /** @var \PKP\user\User $user */
         $userId = $user ? $user->getId() : 0;
         $issue = $this->getAuthorizedContextObject(Application::ASSOC_TYPE_ISSUE);
         $galley = $this->getGalley();
@@ -269,7 +277,7 @@ class IssueHandler extends Handler
                 $subscribedUser = $issueAction->subscribedUser($user, $journal, $issue->getId());
                 if (!$subscribedUser) {
                     // Check if payments are enabled,
-                    $paymentManager = Application::getPaymentManager($journal);
+                    $paymentManager = Application::get()->getPaymentManager($journal);
 
                     if ($paymentManager->purchaseIssueEnabled() || $paymentManager->membershipEnabled()) {
                         // If only pdf files are being restricted, then approve all non-pdf galleys
@@ -284,7 +292,7 @@ class IssueHandler extends Handler
 
                         // If the issue galley has been purchased, then allow reader access
                         $completedPaymentDao = DAORegistry::getDAO('OJSCompletedPaymentDAO'); /** @var OJSCompletedPaymentDAO $completedPaymentDao */
-                        $dateEndMembership = $user->getSetting('dateEndMembership', 0);
+                        $dateEndMembership = $user->getData('dateEndMembership', 0);
                         if ($completedPaymentDao->hasPaidPurchaseIssue($userId, $issue->getId()) || (!is_null($dateEndMembership) && $dateEndMembership > time())) {
                             return true;
                         } else {
@@ -315,15 +323,17 @@ class IssueHandler extends Handler
      * frontend/objects/issue_toc.tpl to function properly (i.e. current issue
      * and view issue).
      *
-     * @param object $issue The issue to display
-     * @param bool $showToc iff false and a custom cover page exists,
-     * 	the cover page will be displayed. Otherwise table of contents
-     * 	will be displayed.
+     * @param \APP\core\Request         $request                    The core request object
+     * @param \APP\issue\Issue          $issue                      The issue to display
+     * @param \APP\journal\Journal|null $journal                    The journal associated with the request
+     * @param bool                      $showToc                    If false and a custom cover page exists,
+     * 	                                                            the cover page will be displayed. Otherwise table of contents
+     * 	                                                            will be displayed.
+     * @param bool                      $withSubscriptionDetails    Should include the subscription related information into the template
      */
-    public static function _setupIssueTemplate($request, $issue, $showToc = false)
+    public static function _setupIssueTemplate(Request $request, Issue $issue, ?Journal $journal = null, $showToc = false, $withSubscriptionDetails = true)
     {
-        $journal = $request->getJournal();
-        $user = $request->getUser();
+        $journal ??= $request->getJournal();
         $templateMgr = TemplateManager::getManager($request);
 
         // Determine pre-publication access
@@ -333,6 +343,9 @@ class IssueHandler extends Handler
             'issueIdentification' => $issue->getIssueIdentification(),
             'issueTitle' => $issue->getLocalizedTitle(),
             'issueSeries' => $issue->getIssueIdentification(['showTitle' => false]),
+            'currentContext' => $journal,
+            'currentJournal' => $journal,
+            'includeIssuePublishDate' => true,
         ]);
 
         $locale = Locale::getLocale();
@@ -378,7 +391,10 @@ class IssueHandler extends Handler
             $issueSubmissionsInSection[$sectionId]['articles'][] = $submission;
         }
 
-        $authorUserGroups = Repo::userGroup()->getCollector()->filterByRoleIds([\PKP\security\Role::ROLE_ID_AUTHOR])->filterByContextIds([$journal->getId()])->getMany()->remember();
+        $authorUserGroups = UserGroup::withRoleIds([\PKP\security\Role::ROLE_ID_AUTHOR])
+            ->withContextIds([$journal->getId()])
+            ->get();
+
         $templateMgr->assign([
             'issue' => $issue,
             'issueGalleys' => $issueGalleyDao->getByIssueId($issue->getId()),
@@ -388,6 +404,10 @@ class IssueHandler extends Handler
         ]);
 
         // Subscription Access
+        $user = $request->getUser();
+        if (!$withSubscriptionDetails || !$user) {
+            return;
+        }
         $issueAction = new IssueAction();
         $subscriptionRequired = $issueAction->subscriptionRequired($issue, $journal);
         $subscribedUser = $issueAction->subscribedUser($user, $journal);
@@ -423,7 +443,7 @@ class IssueHandler extends Handler
                 ($user && $completedPaymentDao->hasPaidPurchaseIssue($user->getId(), $issue->getId()))
         ]);
 
-        $paymentManager = Application::getPaymentManager($journal);
+        $paymentManager = Application::get()->getPaymentManager($journal);
         if ($paymentManager->onlyPdfEnabled()) {
             $templateMgr->assign('restrictOnlyPdf', true);
         }
