@@ -25,7 +25,6 @@ use PKP\config\Config;
 use PKP\context\Context;
 use PKP\core\DataObject;
 use PKP\core\PKPApplication;
-use PKP\core\PKPString;
 use PKP\doi\Doi;
 use PKP\file\FileManager;
 use PKP\file\TemporaryFileManager;
@@ -53,19 +52,6 @@ class DataciteExportPlugin extends DOIPubIdExportPlugin
         $this->agencyPlugin = $agencyPlugin;
     }
 
-    public function register($category, $path, $mainContextId = null)
-    {
-        $success = parent::register($category, $path, $mainContextId);
-        if ($success) {
-            // register hooks. This will prevent DB access attempts before the
-            // schema is installed.
-            if (Application::isUnderMaintenance()) {
-                return true;
-            }
-        }
-        return $success;
-    }
-
     /**
      * @see Plugin::getName()
      */
@@ -119,7 +105,7 @@ class DataciteExportPlugin extends DOIPubIdExportPlugin
      */
     public function getPluginSettingsPrefix()
     {
-        return 'dataciteplugin';
+        return 'datacite';
     }
 
     /**
@@ -263,17 +249,13 @@ class DataciteExportPlugin extends DOIPubIdExportPlugin
 
         $request = Application::get()->getRequest();
         // Get the DOI and the URL for the object.
-        if ($object instanceof Submission) {
-            $doi = $object->getCurrentPublication()->getDoi();
-        } else {
-            $doi = $object->getDoi();
-        }
+        $doi = $object->getStoredPubId('doi');
         assert(!empty($doi));
         $testDOIPrefix = null;
         if ($this->isTestMode($context)) {
             $testDOIPrefix = $this->getSetting($context->getId(), 'testDOIPrefix');
             assert(!empty($testDOIPrefix));
-            $doi = PKPString::regexp_replace('#^[^/]+/#', $testDOIPrefix . '/', $doi);
+            $doi = preg_replace('#^[^/]+/#', $testDOIPrefix . '/', $doi);
         }
         $url = $this->_getObjectUrl($request, $context, $object);
         assert(!empty($url));
@@ -303,7 +285,7 @@ class DataciteExportPlugin extends DOIPubIdExportPlugin
             if ($e->hasResponse()) {
                 $returnMessage = $e->getResponse()->getBody() . ' (' . $e->getResponse()->getStatusCode() . ' ' . $e->getResponse()->getReasonPhrase() . ')';
             }
-            $this->updateDepositStatus($object, Doi::STATUS_ERROR, $returnMessage);
+            $this->updateDepositStatus($object, Doi::STATUS_ERROR);
             return [['plugins.importexport.common.register.error.mdsError', "Registering DOI {$doi}: {$returnMessage}"]];
         }
 
@@ -322,7 +304,7 @@ class DataciteExportPlugin extends DOIPubIdExportPlugin
             if ($e->hasResponse()) {
                 $returnMessage = $e->getResponse()->getBody() . ' (' . $e->getResponse()->getStatusCode() . ' ' . $e->getResponse()->getReasonPhrase() . ')';
             }
-            $this->updateDepositStatus($object, Doi::STATUS_ERROR, $returnMessage);
+            $this->updateDepositStatus($object, Doi::STATUS_ERROR);
             return [['plugins.importexport.common.register.error.mdsError', "Registering DOI {$doi}: {$returnMessage}"]];
         }
         // Test mode submits entirely different DOI and URL so the status of that should not be stored in the database
@@ -338,7 +320,7 @@ class DataciteExportPlugin extends DOIPubIdExportPlugin
      *
      * @param Submission|Issue|Representation $object
      */
-    public function updateDepositStatus(DataObject $object, string $status, ?string $failedMsg = null)
+    public function updateDepositStatus(DataObject $object, string $status)
     {
         assert($object instanceof Submission || $object instanceof Issue || $object instanceof Representation);
         if ($object instanceof Submission) {
@@ -346,8 +328,7 @@ class DataciteExportPlugin extends DOIPubIdExportPlugin
         }
         $doiObject = $object->getData('doiObject');
         $editParams = [
-            'status' => $status,
-            $this->getFailedMsgSettingName() => $failedMsg,
+            'status' => $status
         ];
         if ($status == Doi::STATUS_REGISTERED) {
             $editParams['registrationAgency'] = $this->getName();
@@ -355,36 +336,6 @@ class DataciteExportPlugin extends DOIPubIdExportPlugin
         Repo::doi()->edit($doiObject, $editParams);
     }
 
-    /**
-     * @copydoc DOIPubIdExportPlugin::markRegistered()
-     */
-    public function markRegistered($context, $objects)
-    {
-        foreach ($objects as $object) {
-            // Get all DOIs for each object
-            // Check if submission or issue
-            if ($object instanceof Submission) {
-                $doiIds = Repo::doi()->getDoisForSubmission($object->getId());
-            } else {
-                $doiIds = Repo::doi()->getDoisForIssue($object->getId, true);
-            }
-            foreach ($doiIds as $doiId) {
-                Repo::doi()->markRegistered($doiId);
-            }
-        }
-    }
-
-    /**
-     * Get request failed message setting name.
-     * NB: Changed as of 3.4
-     *
-     * @return string
-     */
-    public function getFailedMsgSettingName()
-    {
-        return $this->getPluginSettingsPrefix() . '_failedMsg';
-    }
-
     /**
      * Test whether the tar binary is available.
      *
@@ -459,18 +410,18 @@ class DataciteExportPlugin extends DOIPubIdExportPlugin
         $url = null;
         switch (true) {
             case $object instanceof Issue:
-                $url = $dispatcher->url($request, PKPApplication::ROUTE_PAGE, $context->getPath(), 'issue', 'view', $object->getBestIssueId(), null, null, true);
+                $url = $dispatcher->url($request, PKPApplication::ROUTE_PAGE, $context->getPath(), 'issue', 'view', [$object->getBestIssueId()], null, null, true, '');
                 break;
             case $object instanceof Submission:
-                $url = $dispatcher->url($request, PKPApplication::ROUTE_PAGE, $context->getPath(), 'article', 'view', $object->getBestId(), null, null, true);
+                $url = $dispatcher->url($request, PKPApplication::ROUTE_PAGE, $context->getPath(), 'article', 'view', [$object->getBestId()], null, null, true, '');
                 break;
             case $object instanceof Galley:
-                $url = $dispatcher->url($request, PKPApplication::ROUTE_PAGE, $context->getPath(), 'article', 'view', [$article->getBestId(), $object->getBestGalleyId()], null, null, true);
+                $url = $dispatcher->url($request, PKPApplication::ROUTE_PAGE, $context->getPath(), 'article', 'view', [$article->getBestId(), $object->getBestGalleyId()], null, null, true, '');
                 break;
         }
         if ($this->isTestMode($context)) {
             // Change server domain for testing.
-            $url = PKPString::regexp_replace('#://[^\s]+/index.php#', '://example.com/index.php', $url);
+            $url = preg_replace('#://[^\s]+/index.php#', '://example.com/index.php', $url);
         }
         return $url;
     }
