@@ -16,7 +16,6 @@
 namespace APP\plugins\generic\datacite;
 
 use APP\core\Application;
-use APP\core\Services;
 use APP\facades\Repo;
 use APP\issue\Issue;
 use APP\plugins\generic\datacite\classes\DataciteSettings;
@@ -66,9 +65,6 @@ class DatacitePlugin extends GenericPlugin implements IDoiRegistrationAgency
                 return true;
             }
 
-            PluginRegistry::register('importexport', new DataciteExportPlugin($this), $this->getPluginPath());
-            $this->_exportPlugin = PluginRegistry::getPlugin('importexport', 'DataciteExportPlugin');
-
             if ($this->getEnabled($mainContextId)) {
                 $this->_pluginInitialization();
             }
@@ -109,9 +105,7 @@ class DatacitePlugin extends GenericPlugin implements IDoiRegistrationAgency
         $items = [];
 
         foreach ($submissions as $submission) {
-            if (in_array(Repo::doi()::TYPE_PUBLICATION, $context->getEnabledDoiTypes())) {
-                $items[] = $submission;
-            }
+            $items[] = $submission;
             if (in_array(Repo::doi()::TYPE_REPRESENTATION, $context->getEnabledDoiTypes())) {
                 foreach ($submission->getCurrentPublication()->getData('galleys') as $galley) {
                     if ($galley->getDoi()) {
@@ -136,9 +130,7 @@ class DatacitePlugin extends GenericPlugin implements IDoiRegistrationAgency
         $items = [];
 
         foreach ($submissions as $submission) {
-            if (in_array(Repo::doi()::TYPE_PUBLICATION, $context->getEnabledDoiTypes())) {
-                $items[] = $submission;
-            }
+            $items[] = $submission;
             if (in_array(Repo::doi()::TYPE_REPRESENTATION, $context->getEnabledDoiTypes())) {
                 foreach ($submission->getCurrentPublication()->getData('galleys') as $galley) {
                     if ($galley->getDoi()) {
@@ -185,29 +177,6 @@ class DatacitePlugin extends GenericPlugin implements IDoiRegistrationAgency
         ];
     }
 
-    /**
-     * Adds DataCite specific info to Repo::doi()->markRegistered()
-     *
-     * @param string $hookName Doi::markRegistered
-     *
-     */
-    public function editMarkRegisteredParams(string $hookName, array $args): bool
-    {
-        $editParams = &$args[0];
-        $editParams[$this->_getFailedMsgSettingName()] = null;
-        return HOOK::CONTINUE;
-    }
-
-    /**
-     * Get request failed message setting name.
-     * NB: Change from 3.3.x to camelCase (over crossref::failedMsg)
-     *
-     */
-    private function _getFailedMsgSettingName(): string
-    {
-        return $this->getName() . '_failedMsg';
-    }
-
     /**
      * Includes plugin in list of configurable registration agencies for DOI depositing functionality
      *
@@ -222,7 +191,6 @@ class DatacitePlugin extends GenericPlugin implements IDoiRegistrationAgency
         /** @var Collection<int,IDoiRegistrationAgency> $enabledRegistrationAgencies */
         $enabledRegistrationAgencies = &$args[0];
         $enabledRegistrationAgencies->add($this);
-        return HOOK::CONTINUE;
     }
 
     /**
@@ -234,7 +202,7 @@ class DatacitePlugin extends GenericPlugin implements IDoiRegistrationAgency
         $settingsObject = $this->getSettingsObject();
 
         /** @var PKPSchemaService $schemaService */
-        $schemaService = Services::get('schema');
+        $schemaService = app()->get('schema');
         $requiredProps = $schemaService->getRequiredProps($settingsObject::class);
 
         foreach ($requiredProps as $requiredProp) {
@@ -267,7 +235,7 @@ class DatacitePlugin extends GenericPlugin implements IDoiRegistrationAgency
      */
     public function getErrorMessageKey(): ?string
     {
-        return $this->_getFailedMsgSettingName();
+        return null;
     }
 
     /**
@@ -302,39 +270,11 @@ class DatacitePlugin extends GenericPlugin implements IDoiRegistrationAgency
      */
     private function _pluginInitialization()
     {
-        Hook::add('DoiSettingsForm::setEnabledRegistrationAgencies', [$this, 'addAsRegistrationAgencyOption']);
-        Hook::add('DoiSetupSettingsForm::getObjectTypes', [$this, 'addAllowedObjectTypes']);
-        Hook::add('DoiListPanel::setConfig', [$this, 'addRegistrationAgencyName']);
-        Hook::add('Doi::markRegistered', [$this, 'editMarkRegisteredParams']);
-        Hook::add('Schema::get::doi', [$this, 'addToSchema']);
-    }
+        PluginRegistry::register('importexport', new DataciteExportPlugin($this), $this->getPluginPath());
 
-    /**
-     * Add properties for DataCite to the DOI entity for storage in the database.
-     *
-     * @param string $hookName `Schema::get::doi`
-     * @param array $args [
-     *
-     *      @option stdClass $schema
-     * ]
-     *
-     */
-    public function addToSchema(string $hookName, array $args): bool
-    {
-        $schema = &$args[0];
-
-        $settings = [
-            $this->_getFailedMsgSettingName(),
-        ];
-
-        foreach ($settings as $settingName) {
-            $schema->properties->{$settingName} = (object) [
-                'type' => 'string',
-                'apiSummary' => true,
-                'validation' => ['nullable'],
-            ];
-        }
-        return HOOK::CONTINUE;
+        Hook::add('DoiSettingsForm::setEnabledRegistrationAgencies', $this->addAsRegistrationAgencyOption(...));
+        Hook::add('DoiSetupSettingsForm::getObjectTypes', $this->addAllowedObjectTypes(...));
+        Hook::add('DoiListPanel::setConfig', $this->addRegistrationAgencyName(...));
     }
 
     /**
@@ -351,6 +291,7 @@ class DatacitePlugin extends GenericPlugin implements IDoiRegistrationAgency
     {
         $config = &$args[0];
         $config['registrationAgencyNames'][$this->_getExportPlugin()->getName()] = $this->getRegistrationAgencyName();
+
         return HOOK::CONTINUE;
     }
 
