@@ -17,7 +17,7 @@ namespace APP\plugins\themes\default;
 use APP\core\Application;
 use APP\file\PublicFileManager;
 use PKP\config\Config;
-use PKP\session\SessionManager;
+use PKP\core\PKPSessionGuard;
 
 class DefaultThemePlugin extends \PKP\plugins\ThemePlugin
 {
@@ -26,7 +26,7 @@ class DefaultThemePlugin extends \PKP\plugins\ThemePlugin
      */
     public function isActive()
     {
-        if (SessionManager::isDisabled()) {
+        if (PKPSessionGuard::isSessionDisable()) {
             return true;
         }
         return parent::isActive();
@@ -155,10 +155,9 @@ class DefaultThemePlugin extends \PKP\plugins\ThemePlugin
         }
 
         // Update colour based on theme option
-        if (($baseColour = $this->getOption('baseColour')) !== '#1E6292') {
-            if (!preg_match('/^#[0-9a-fA-F]{1,6}$/', $baseColour)) $baseColour = '#1E6292'; // pkp/pkp-lib#11974
-            $additionalLessVariables[] = '@bg-base:' . $baseColour . ';';
-            if (!$this->isColourDark($baseColour)) {
+        if ($this->getOption('baseColour') !== '#1E6292') {
+            $additionalLessVariables[] = '@bg-base:' . $this->getOption('baseColour') . ';';
+            if (!$this->isColourDark($this->getOption('baseColour'))) {
                 $additionalLessVariables[] = '@text-bg-base:rgba(0,0,0,0.84);';
                 $additionalLessVariables[] = '@bg-base-border-color:rgba(0,0,0,0.2);';
             }
@@ -194,8 +193,9 @@ class DefaultThemePlugin extends \PKP\plugins\ThemePlugin
 
         // Load jQuery from a CDN or, if CDNs are disabled, from a local copy.
         $min = Config::getVar('general', 'enable_minified') ? '.min' : '';
-        $jquery = $request->getBaseUrl() . '/lib/pkp/lib/vendor/components/jquery/jquery' . $min . '.js';
-        $jqueryUI = $request->getBaseUrl() . '/lib/pkp/lib/vendor/components/jqueryui/jquery-ui' . $min . '.js';
+        $jquery = $request->getBaseUrl() . '/js/build/jquery/jquery' . $min . '.js';
+        $jqueryUI = $request->getBaseUrl() . '/js/build/jquery-ui/jquery-ui' . $min . '.js';
+
         // Use an empty `baseUrl` argument to prevent the theme from looking for
         // the files within the theme directory
         $this->addScript('jQuery', $jquery, ['baseUrl' => '']);
@@ -206,6 +206,11 @@ class DefaultThemePlugin extends \PKP\plugins\ThemePlugin
         $this->addScript('bsUtil', 'js/lib/bootstrap/util.js');
         $this->addScript('bsDropdown', 'js/lib/bootstrap/dropdown.js');
 
+        // Load Swiper for carousel
+        $this->addScript('swiper', 'js/lib/swiper/swiper-bundle' . $min . '.js');
+        $this->addStyle('swiper', 'js/lib/swiper/swiper-bundle' . $min . '.css');
+        $this->addScript('swiper-i18n', $this->getSwiperI18n(), ['inline' => true]);
+
         // Load custom JavaScript for this theme
         $this->addScript('default', 'js/main.js');
 
@@ -224,14 +229,6 @@ class DefaultThemePlugin extends \PKP\plugins\ThemePlugin
         return $this->getPluginPath() . '/settings.xml';
     }
 
-    /** @see ThemePlugin::saveOption */
-    public function saveOption($name, $value, $contextId = null) {
-        // Validate the base colour setting value.
-        if ($name == 'baseColour' && !preg_match('/^#[0-9a-fA-F]{1,6}$/', $value)) $value = null; // pkp/pkp-lib#11974
-
-        parent::saveOption($name, $value, $contextId);
-    }
-
     /**
      * Get the name of the settings file to be installed site-wide when
      * OJS is installed.
@@ -262,6 +259,17 @@ class DefaultThemePlugin extends \PKP\plugins\ThemePlugin
     {
         return __('plugins.themes.default.description');
     }
+
+    /**
+     * Get the locale strings for the swiper carousel
+     */
+    public function getSwiperI18n(): string
+    {
+        return 'var pkpDefaultThemeI18N = ' . json_encode([
+            'nextSlide' => __('plugins.themes.default.nextSlide'),
+            'prevSlide' => __('plugins.themes.default.prevSlide'),
+        ]);
+    }
 }
 
 if (!PKP_STRICT_MODE) {
